using System;
using System.Collections;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Windows.Forms;
using System.Text;

using Syncfusion.Drawing;
using Syncfusion.Styles;
using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;

namespace _39539
{
	/// <summary>
	/// Summary description for MyDropDownColorUICellRenderer.
	/// </summary>
	public class MyDropDownColorUICellRenderer : GridDropDownCellRenderer
	{
		
			ColorUIControl colorUI;

			/// <summary>
			/// Initializes a new GridDropDownColorUICellRenderer object for the given GridControlBase
			/// and GridCellModelBase.
			/// </summary>
			/// <param name="grid">The <see cref="GridControlBase"/> that displays this cell renderer.</param>
			/// <param name="cellModel">The <see cref="GridCellModelBase"/> that holds data for this cell renderer that should
			/// be shared among views.</param>
			/// <remarks>References to GridControlBase, 
			/// and GridCellModelBase will be saved.</remarks>
			public MyDropDownColorUICellRenderer(GridControlBase grid, GridCellModelBase cellModel)
				: base(grid, cellModel)
			{
				DropDownButton = new GridCellButton(this);
				DropDownButton.Text = "@";
			}

			/// <override/>
			protected /*internal*/ override void InitializeDropDownContainer()
			{
				base.InitializeDropDownContainer();
				
				colorUI = new ColorUIControl();
				colorUI.Dock = DockStyle.Fill;
				colorUI.Visible = true;
				colorUI.ColorGroups = ColorUIGroups.CustomColors;
				colorUI.ColorSelected += new EventHandler(ColorUIColorSelected);

				this.DropDownContainer.Controls.Add(colorUI);

			}

			/// <override/>
			public override void DropDownContainerShowingDropDown(object sender, CancelEventArgs e)
			{
				this.DropDownContainer.Size = new Size(500, 500);
				Color color = Grid.GetBackColor(Grid.Model[RowIndex, ColIndex].Interior.BackColor);
				try
				{
					color = ColorConvert.ColorFromString(TextBox.Text);
				}
				catch //(Exception ex)
				{
					//				TraceUtil.TraceExceptionCatched(ex);
					//				if (!ExceptionManager.RaiseExceptionCatched(this, ex))
					//					throw ex;
				}
				colorUI.Start(color);

				Size size = new Size(208,230);
				GridCurrentCellShowingDropDownEventArgs ce = new GridCurrentCellShowingDropDownEventArgs(size);
				Grid.RaiseCurrentCellShowingDropDown(ce);
				if (ce.Cancel)
				{
					e.Cancel = true;
					return;
				}

				this.DropDownContainer.Size = ce.Size;
			}

			/// <override/>
			public override void DropDownContainerShowedDropDown(object sender, EventArgs e)
			{
				DropDownContainer.FocusParent();
				NotifyShowedDropDown();
			}

			/// <override/>
			public override void OnPrepareViewStyleInfo(GridPrepareViewStyleInfoEventArgs e)
			{
				try
				{
					string displayText = Model.GetFormattedOrActiveTextAt(e.RowIndex, e.ColIndex, e.Style);
					if (displayText.Length > 0)
					{
						Color color = ColorConvert.ColorFromString(displayText);
						e.Style.Interior = new BrushInfo(color);
					}
				}
				catch //(Exception ex)
				{
					//TraceUtil.TraceExceptionCatched(ex);
					//				if (!ExceptionManager.RaiseExceptionCatched(this, ex))
					//					throw ex;
				}
			}

			/// <override/>
			public override void ChildClosing(IPopupChild childUI, PopupCloseType popupCloseType)
			{
				if (popupCloseType == PopupCloseType.Done && !IsReadOnly())
				{
					if (!this.NotifyCurrentCellChanging())
						return;

					TextBox.Text = ColorConvert.ColorToString(colorUI.SelectedColor, true);
					TextBox.SelectionStart = 0;
					TextBox.SelectionLength = 0;
					TextBox.Modified = true;
					TextBox.BackColor = colorUI.SelectedColor;
					TextBox.Focus();
					Grid.InvalidateRange(GridRangeInfo.Cell(RowIndex, ColIndex));
					this.NotifyCurrentCellChanged();
				}
				DropDownContainerCloseDropDown(childUI, new PopupClosedEventArgs(popupCloseType));
			}

			/// <override/>
			protected override void TextBoxChanged(object sender, EventArgs e)
			{
				base.TextBoxChanged(sender, e);

				try
				{
					Color color = ColorConvert.ColorFromString(TextBoxText);
					TextBox.BackColor = Grid.GetBackColor(color);
				}
				catch //(Exception ex)
				{
					//				TraceUtil.TraceExceptionCatched(ex);
					//				if (!ExceptionManager.RaiseExceptionCatched(this, ex))
					//					throw ex;
				}
			}

			void ColorUIColorSelected(object sender, EventArgs e)
			{
				CurrentCell.CloseDropDown(PopupCloseType.Done);
			}
		
	}
}
